@@ -1,7 +1,7 @@
 /**
  * about.c - about dialog for SciteProj
  *
- *	 Copyright 2008-2017 Andreas Rönnquist
+ *	 Copyright 2008-2019 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -32,7 +32,7 @@
 
 #include "prefs.h"
 
-gchar *homepage_string=(gchar*)"http://www.gusnan.se/sciteproj";
+gchar *homepage_string=(gchar*)"https://www.nongnu.org/sciteproj";
 
 gchar *sVersion = (gchar*)SCITEPROJ_VERSION;
 
@@ -40,8 +40,8 @@ static GtkWidget *window;
 
 void create_about_dialog();
 
-gboolean handle_about_close_event(GtkWidget *widget,GdkEvent *event,gpointer user_data);
-void link_button_cb(GtkButton *button,gpointer user_data);
+gboolean handle_about_close_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+void link_button_cb(GtkButton *button, gpointer user_data);
 
 gchar *version_string = NULL;
 
@@ -58,16 +58,27 @@ void show_about_dialog()
 }
 
 
+/**
+ *  Handle keyboard pressing escape in about dialog
+ */
+gboolean handle_keyboard_event_cb(GtkWidget *widget, GdkEventKey *event, gpointer data)
+{
+    if (event->keyval == GDK_KEY_Escape) {
+        // printf("Escape pressed.\n");
+        gtk_widget_hide(window);
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
+
 /**
  *	creates a new dialog box, and fills it will all necessary information
  */
 void create_about_dialog()
 {
-#if GTK_MAJOR_VERSION >= 3
 	GtkWidget *grid;
-#else
-	GtkWidget *vbox;
-#endif
 	GtkWidget *textview_info;
 	GtkWidget *logo_image;
 	GtkWidget *linkbutton;
@@ -96,42 +107,28 @@ void create_about_dialog()
 	gtk_widget_set_size_request(window, 500, 400);
 
 	// Make a container
-#if GTK_MAJOR_VERSION >= 3
 	grid = gtk_grid_new();
 
 	gtk_grid_set_row_spacing (GTK_GRID (grid), 6);
 
 	gtk_container_add(GTK_CONTAINER(window), grid);
-#else
-	vbox = gtk_vbox_new(FALSE,5);
-
-	gtk_container_add(GTK_CONTAINER(window), vbox);
-#endif
 
 	logo_image = gtk_image_new_from_pixbuf(program_icon_pixbuf);
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_grid_attach(GTK_GRID(grid), logo_image, 0, 0, 5, 1);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), logo_image, FALSE, FALSE, 0);
-#endif
 
 	sciteproj_label = gtk_label_new(NULL);
 	gtk_label_set_selectable(GTK_LABEL(sciteproj_label), FALSE);
 	gtk_label_set_markup(GTK_LABEL(sciteproj_label), "<big><b>SciteProj</b></big>");
 
 
-#if GTK_MAJOR_VERSION>=3
 	gtk_grid_attach_next_to(GTK_GRID(grid), sciteproj_label, logo_image, GTK_POS_BOTTOM, 5, 1);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), sciteproj_label, FALSE, FALSE, 0);
-#endif
 
 	// Show version of SciteProj
 
 	gchar *about_dialog_version_string;
 
-#ifdef _DEBUG
+ #ifdef _DEBUG
 	about_dialog_version_string = g_strdup_printf("%s DEBUG",version_string);
 #else
 	about_dialog_version_string = g_strdup_printf("%s", version_string);
@@ -140,11 +137,7 @@ void create_about_dialog()
 	version_string_label = gtk_label_new(about_dialog_version_string);
 	gtk_label_set_selectable(GTK_LABEL(version_string_label), FALSE);
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_grid_attach_next_to(GTK_GRID(grid), version_string_label, sciteproj_label, GTK_POS_BOTTOM, 5, 1);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), version_string_label, FALSE, FALSE, 0);
-#endif
 
 	// Show SciteProj copyrights
 	copyrightstring = g_strdup_printf("Copyright (C) 2008-2017 Andreas Rönnquist <andreas@ronnquist.net>");
@@ -152,11 +145,7 @@ void create_about_dialog()
 	copyright_label = gtk_label_new(copyrightstring);
 	gtk_label_set_selectable(GTK_LABEL(copyright_label), FALSE);
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_grid_attach_next_to(GTK_GRID(grid), copyright_label, version_string_label, GTK_POS_BOTTOM, 5, 1);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), copyright_label, FALSE, FALSE, 0);
-#endif
 
 	// show GTK versions
 	gchar *gtk_string = g_strdup_printf("GTK+ %d.%d.%d / GLib %d.%d.%d",
@@ -168,24 +157,13 @@ void create_about_dialog()
 
 	gtk_label_set_selectable(GTK_LABEL(gtk_version_label), FALSE);
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_grid_attach_next_to(GTK_GRID(grid), gtk_version_label, copyright_label, GTK_POS_BOTTOM, 5, 1);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), gtk_version_label, FALSE, FALSE, 0);
-
-	GtkWidget *hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-#endif
 
 
 	// Show a link to the SciteProj homepage
 	linkbutton = gtk_link_button_new_with_label(homepage_string, homepage_string);
 
-#if GTK_MAJOR_VERSION>=3
 	gtk_grid_attach_next_to(GTK_GRID(grid), linkbutton, gtk_version_label, GTK_POS_BOTTOM, 5, 1);
-#else
-	gtk_box_pack_start(GTK_BOX(hbox), linkbutton, TRUE, FALSE, 0);
-#endif
 
 	// New notebook - we want tabs for different sets of text
 
@@ -285,20 +263,14 @@ void create_about_dialog()
 
 	gtk_container_add(GTK_CONTAINER(scrolled_window_info), textview_info);
 
-	//gtk_box_pack_start(GTK_BOX(vbox), scrolled_window, TRUE, TRUE, 0);
-
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), scrolled_window_info, notebook_label1);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), scrolled_window_license, notebook_label2);
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_widget_set_vexpand(notebook, TRUE);
 
 	gtk_widget_set_hexpand(notebook, TRUE);
 
 	gtk_grid_attach_next_to(GTK_GRID(grid), notebook, linkbutton/*gtk_version_label*/, GTK_POS_BOTTOM, 5, 1);
-#else
-	gtk_box_pack_start(GTK_BOX(vbox), notebook, TRUE, TRUE, 0);
-#endif
 
 	gtk_text_buffer_place_cursor(textbuffer_info, &iter);
 	gtk_text_buffer_select_range(textbuffer_info, &iter, &iter);
@@ -308,23 +280,10 @@ void create_about_dialog()
 	gtk_button_set_use_underline(GTK_BUTTON(ok_button), TRUE);
 	gtk_button_set_label(GTK_BUTTON(ok_button), "_OK");
 
-#if GTK_MAJOR_VERSION >= 3
 	gtk_widget_set_halign(ok_button, GTK_ALIGN_END);
 	gtk_widget_set_hexpand(ok_button, FALSE);
-#endif
 
-	//gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
-	//	gtk_grid_attach_next_to(GTK_GRID(grid), hbox, notebook, GTK_POS_BOTTOM, 5, 1);
-
-#if GTK_MAJOR_VERSION >= 3
 	gtk_grid_attach_next_to(GTK_GRID(grid), ok_button, notebook, GTK_POS_BOTTOM, 5, 1);
-#else
-	GtkWidget *ok_button_hbox = gtk_hbox_new(FALSE,0);
-
-	gtk_box_pack_end(GTK_BOX(ok_button_hbox), ok_button, FALSE, FALSE, 0);
-
-	gtk_box_pack_start(GTK_BOX(vbox), ok_button_hbox, FALSE, FALSE, 0);
-#endif
 
 	gtk_widget_grab_focus(ok_button);
 
@@ -340,6 +299,11 @@ void create_about_dialog()
 	g_signal_connect(G_OBJECT(window), "delete-event", G_CALLBACK(handle_about_close_event), window);
 	g_signal_connect(G_OBJECT(linkbutton), "released", G_CALLBACK(link_button_cb), linkbutton);
 
+    // Handle ESC in about window
+    gtk_widget_add_events(window, GDK_KEY_PRESS_MASK);
+
+    g_signal_connect(G_OBJECT(window), "key_press_event", G_CALLBACK(handle_keyboard_event_cb), NULL);
+
 	gtk_widget_show_all(window);
 
 }
